@@ -39,7 +39,7 @@ class BasePublisher(object):
         def view(request, *args, **kwargs):
             '''A wrapper view to instanciate and dispatch'''
             self = cls(request, *args, **kwargs)
-            return self.dispatch(request, *args, **kwargs)
+            return self.dispatch(request, **kwargs)
 
         if api_name:
             name = '%s_%s' % (api_name, cls.api_name)
@@ -49,7 +49,7 @@ class BasePublisher(object):
         return [
             url(r'^object/(?P<object_id>[-\w]+)/',
                 include(patterns('',
-                    url(r'^(?P<action>\w+)/(?P<argument>.+)/?$', view,
+                    url(r'^(?P<action>\w+)/(?P<argument>.+?)/?$', view,
                         name='%s_object_action_arg' % name
                     ),
                     url(r'^(?P<action>\w+)/?$', view,
@@ -60,7 +60,7 @@ class BasePublisher(object):
                     ),
                 ))
             ),
-            url(r'^(?P<action>\w+)/(?P<argument>.+)/$',
+            url(r'^(?P<action>\w+)/(?P<argument>.+?)/?$',
                 view,
                 name='%s_list_action_arg' % name,
             ),
@@ -78,6 +78,7 @@ class BasePublisher(object):
     def dispatch(self, request, action='default', object_id=None, **kwargs):
         '''View dispatcher called by Django'''
         self.action = action
+        self.object_id = object_id
         method = request.method.lower()
         self.mode = prefix = 'object' if object_id else 'list'
         handler = getattr(self, '%s_%s_%s' % (prefix, method, action), None)
@@ -87,14 +88,12 @@ class BasePublisher(object):
         if handler is None:
             raise http.Http404
         # Do we need to pass any of this?
-        return self.execute(handler, request, action=action, object_id=object_id,
-            **kwargs
-        )
+        return self.execute(handler)
 
-    def execute(self, handler, *args, **kwargs):
+    def execute(self, handler, **kwargs):
         '''This allows wrapping calls to handler functions'''
         try:
-            return handler(*args, **kwargs)
+            return handler(self.request, action=self.action, object_id=self.object_id, **kwargs)
         except http.BaseHttpResponse as response:
             return response
 
